==> com.liferay.commerce.dashboard.web-3.0.21.jar: META-INF/resources/js/history/HistoryChart.es.js <==
Liferay.Loader.define("commerce-dashboard-web@3.0.21/js/history/HistoryChart.es", ['module', 'exports', 'require', 'frontend-js-react-web$react', '../ChartWrapper.es'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = HistoryChart;

    var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

    var _ChartWrapper = _interopRequireDefault(require("../ChartWrapper.es"));

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * The contents of this file are subject to the terms of the Liferay Enterprise
     * Subscription License ("License"). You may not use this file except in
     * compliance with the License. You can obtain a copy of the License by
     * contacting Liferay, Inc. See the License for the specific language governing
     * permissions and limitations under the License, including but not limited to
     * distribution rights of the Software.
     */
    function HistoryChart(_ref) {
      var _APIBaseUrl = _ref._APIBaseUrl,
          _accountIdParamName = _ref._accountIdParamName,
          _commerceAccountId = _ref._commerceAccountId,
          _noAccountErrorMessage = _ref._noAccountErrorMessage,
          noDataErrorMessage = _ref.noDataErrorMessage;

      return (/*#__PURE__*/_react.default.createElement(_ChartWrapper.default, {
          data: {
            axis: {
              x: {
                categories: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep'],
                type: 'category'
              }
            },
            color: {
              pattern: ['#4B9BFF']
            },
            data: {
              columns: [['2019', 30, 200, 100, 400, 150, 250, 50, 100, 250], ['2018', 100, 30, 200, 320, 50, 150, 230, 80, 150]],
              order: null,
              type: 'line'
            },
            grid: {
              x: {
                // lines: COLUMNS[0].map((c, i) => ({value: i}))
                show: false
              }
            },
            legend: {
              show: false
            },
            line: {
              classes: ['bb-line-past', 'bb-line-present']
            },
            point: {
              show: false
            }
          },
          noDataErrorMessage: noDataErrorMessage
        })
      );
    }
    //# sourceMappingURL=HistoryChart.es.js.map
  }
});
//# sourceMappingURL=HistoryChart.es.js.map

==> com.liferay.commerce.dashboard.web-3.0.22.jar: META-INF/resources/js/history/HistoryChart.es.js <==
Liferay.Loader.define("commerce-dashboard-web@3.0.22/js/history/HistoryChart.es", ['module', 'exports', 'require', 'frontend-js-react-web$react', '../ChartWrapper.es'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = HistoryChart;

    var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

    var _ChartWrapper = _interopRequireDefault(require("../ChartWrapper.es"));

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * The contents of this file are subject to the terms of the Liferay Enterprise
     * Subscription License ("License"). You may not use this file except in
     * compliance with the License. You can obtain a copy of the License by
     * contacting Liferay, Inc. See the License for the specific language governing
     * permissions and limitations under the License, including but not limited to
     * distribution rights of the Software.
     */
    function HistoryChart({
      _APIBaseUrl,
      _accountIdParamName,
      _commerceAccountId,
      _noAccountErrorMessage,
      noDataErrorMessage
    }) {
      return (/*#__PURE__*/_react.default.createElement(_ChartWrapper.default, {
          data: {
            axis: {
              x: {
                categories: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep'],
                type: 'category'
              }
            },
            color: {
              pattern: ['#4B9BFF']
            },
            data: {
              columns: [['2019', 30, 200, 100, 400, 150, 250, 50, 100, 250], ['2018', 100, 30, 200, 320, 50, 150, 230, 80, 150]],
              order: null,
              type: 'line'
            },
            grid: {
              x: {
                // lines: COLUMNS[0].map((c, i) => ({value: i}))
                show: false
              }
            },
            legend: {
              show: false
            },
            line: {
              classes: ['bb-line-past', 'bb-line-present']
            },
            point: {
              show: false
            }
          },
          noDataErrorMessage: noDataErrorMessage
        })
      );
    }
    //# sourceMappingURL=HistoryChart.es.js.map
  }
});
//# sourceMappingURL=HistoryChart.es.js.map
